//
//  ImageView.m
//  BarCodeScanning
//
//  Created by Yogesh Arora on 19/12/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "AppDelegate.h"
#import "ImageView.h"

@implementation ImageView

@synthesize image = _image;

- (id) initWithFrame:(NSRect)frame
{
    self = [super initWithFrame:frame];
    if (self) 
    {
        //Inialization code here
        self.image = nil;
        
        //Registering dragging types
        [self registerForDraggedTypes:[NSArray arrayWithObjects:NSFilenamesPboardType, nil]];
    }
    return self;
}

#pragma Mark - Dragging Methods

//Draw a view
- (void) drawRect:(NSRect)dirtyRect
{
    if (self.image == nil)
    {
        [[NSColor blackColor] set];
		NSRectFill(dirtyRect);
    }
    NSRect viewBounds = [self bounds];
    [super drawRect:dirtyRect];
    
    //Drawing an image
    [self.image compositeToPoint:(viewBounds.origin) operation:NSCompositeSourceOver];
}

//Invoke during dragging
- (NSDragOperation) draggingEntered:(id<NSDraggingInfo>)sender
{
    if ((NSDragOperationGeneric & [sender draggingSourceOperationMask]) == NSDragOperationGeneric) 
        return NSDragOperationGeneric;
    
	return NSDragOperationNone;	
}

//If yes perform successfully dragging operation
- (BOOL) prepareForDragOperation:(id <NSDraggingInfo>)sender
{
    return YES;
} 

//Finally place drag image to view
- (BOOL) performDragOperation:(id <NSDraggingInfo>)sender 
{
    //Creating pasteboard object
    NSPasteboard* pastboard = [sender draggingPasteboard];
	NSArray* imgTypeArr = [NSArray arrayWithObjects:NSFilenamesPboardType, nil];
	NSString* desiredType = [pastboard availableTypeFromArray:imgTypeArr];
	
    //Write file URLs to the pasteboard
	if ([desiredType isEqualToString:NSFilenamesPboardType]) 
    {
        NSArray* fileNamesArr = [pastboard propertyListForType:@"NSFilenamesPboardType"];
		NSString* path = [fileNamesArr objectAtIndex:0];
        
        //Setting filepath
        [_gAppDelegate setFilePath:path];
		NSImage* newImage = [[NSImage alloc] initWithContentsOfFile:path];
        
        if (newImage == nil) 
        	return NO;
        self.image = newImage;	
        [newImage release];
		[self setNeedsDisplay:YES];
		return YES;
    }
	return NO;
} 

- (void) concludeDragOperation:(id <NSDraggingInfo>)sender 
{
    //Re-draw a view
    [self setNeedsDisplay:YES];
}

#pragma  Mark - Other Methods
- (void) dealloc
{
    [_image release];
    
    [super dealloc];
}

@end
